'''Game main module.

Contains the entry point used by the run_game.py script.

Feel free to put all your game code here, or in other modules in this "gamelib"
package.
'''

import pygame
import random

winds = []
clouds = []
feathers = []
screen = pygame.display.set_mode((640, 480))

def on_screen_text(text, x, y, color, fontsize):
	font = pygame.font.Font(None, fontsize)
	render = font.render(text, 1, color)
	screen.blit(render, (x, y))

class Angel:
	def Update(self, mouse_x, time_passed):
		self.dir_y = 0
		if mouse_x - 20 > self.x:
			self.x = self.x + 3
		elif mouse_x - 20 < self.x:
			self.x = self.x - 3
		self.feathers_lost = time_passed
		for i in winds:
			if self.x > i.x - 30 and self.x < i.x + 30:
				self.dir_y -= i.power
		self.dir_y += self.feathers_lost/6
		if self.stop <= 0:
			self.y = self.y + self.dir_y
		self.stop -= 1
		if self.y < 0:
			self.y = 0
		if self.feathers_lost >= 20 and self.feathers_lost < 40:
			self.image = pygame.image.load("./data/angel-neutral.png")
		elif self.feathers_lost >= 40:
			self.image = pygame.image.load("./data/angel-bad.png")
		
	def __init__(self):
		self.x = random.randint(0, 640)
		self.y = 15
		self.feathers_lost = 0
		self.dir_y = 0
		self.image = pygame.image.load("./data/angel-good.png")
		self.stop = 0
		
class Wind:
	def Update(self, time_passed):
		if time_passed == self.timestart + self.time:
			winds.remove(self)			

	def __init__(self, time_passed):
		self.x = random.randint(0, 600)
		self.y = 420
		self.power = random.randint(0, 9)
		self.time = random.randint(0, 10)
		self.timestart = time_passed
		self.active = 0
		self.image = pygame.image.load("./data/komin.png")
		winds.append(self)
		
class Cloud:
	def __init__(self):
		self.x = -100
		self.y = random.randint(30, 370)
		self.speed = random.randint(1, 3)
		self.image = pygame.image.load("./data/cloud.png")
		clouds.append(self)
		
	def Update(self, angel):
		self.x += self.speed
		if self.x > 640:
			clouds.remove(self)
		if angel.x >= self.x and angel.x <= self.x + 60 and angel.y >= self.y - 40 and angel.y <= self.y + 30:
			angel.stop = 25
			
class Feather:
	def __init__(self, angel_x, angel_y):
		self.x = angel_x + 20
		self.y = angel_y + 80
		self.image = pygame.image.load("./data/feather.png")
		feathers.append(self)
	def Update(self):
		if self.y < 465:
			self.y += random.randint(0 , 2)
			self.x += random.randint(-1 , 1)
		for i in winds:
			if self.x > i.x - 5 and self.x < i.x + 30:
				self.y -= i.power	
		
def main():
	pygame.init()
	angel = Angel()
	clock = pygame.time.Clock()
	time = 0
	time_passed = 0
	pygame.display.set_caption("Tenshee")
	running = 0
	grass_image = pygame.image.load("./data/grass.png")
	
	while True:
    		#main event loop
    		if running == 3:
    			pygame.time.wait(3000)
    		event = pygame.event.poll()
    		if event.type == pygame.QUIT or running == 3:
    			return False
    		mouse_x, mouse_y = pygame.mouse.get_pos()
    		#check the time
    		clock.tick(40)
		time += clock.get_time()
		if time > 2000:
			time -= 2000
			time_passed += 1
			#add a new wind and a new cloud
			w = Wind(time_passed)
			c = Cloud()
			f = Feather(angel.x, angel.y)
    		#some drawing 
       		screen.fill((127, 215, 238))
    		angel.Update(mouse_x, time_passed)
    		if angel.y > 440:
    			running = 3
    			print "Your angel died after losing %s feathers" %time_passed
    		screen.blit(grass_image, (0, 440))
    		screen.blit(angel.image, (angel.x, angel.y))
    		for i in feathers:
    			i.Update()
    			screen.blit(i.image, (i.x, i.y))
    		for i in clouds:
    			i.Update(angel)
    			screen.blit(i.image, (i.x, i.y))
    		for i in winds:
    			i.Update(time_passed)
    			screen.blit(i.image, (i.x, i.y))
    			on_screen_text(str(i.power), i.x + 15, i.y + 35, (0,0,0), 30)
    		on_screen_text("Feathers lost: %s" %time_passed, 5, 5, (255, 255, 255), 36)
    		on_screen_text("fps: %.4s" %clock.get_fps(), 5, 468, (255, 255, 255), 20)
    		if time_passed < 1:
    			on_screen_text("Keep the angel in the air as long as you can!", 50, 222, (255, 255, 255), 36)
    		pygame.time.wait(10)
    		if angel.y > 440:
    			on_screen_text("Your angel died after losing %s feathers" %time_passed, 80, 222, (255, 0, 0), 36)
    		pygame.display.flip()
